==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/co/hco14.h <==
/* @lastChanged: "1998-06-22  16:21"

  * @filename:   hco00.h
  * @purpose:    "Currency Interface for C++ Persistent Objects"
  * @release:    7.1.0.0
  * @see:        "http://www.bea.sap-ag.de/doku/rel-7.1/hco00.html"
  *
  * @copyright:  "Copyright by   SAP AG, 1998"


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*/

#if !defined (__liveCacheCurrency_INCLUDED)
#define __liveCacheCurrency_INCLUDED

#include "livecache.h"    /* no check */ /* PTS 1108379 */

#define MAX_CURRENCY_VAL 9223372036854775807I64
#define DBP_CURRENCY_1   1000

class DECLSPEC_IMPORT OmsPacked {
public :
  OmsTypeInt64 toInt64_16();
  void   toPacked(OmsTypeInt64,int);
private :
 unsigned char m_packed[16];      
};

class DbpCurrency {
public :
  DbpCurrency(){}
  
  inline DbpCurrency(const OmsTypePacked_8_3&);
  inline void dbpToPacked_8_3 (OmsTypePacked_8_3&);
  inline operator OmsTypePacked_8_3();
  inline OmsTypeInt64 dbpGetVal() const;
  inline void dbpPutVal(OmsTypeInt64);

  inline const DbpCurrency& operator =( const OmsTypePacked_8_3& cur );

  // Currency Comparison
  inline bool operator==(const DbpCurrency& cur) const;
	inline bool operator!=(const DbpCurrency& cur) const;
	inline bool operator< (const DbpCurrency& cur) const;
	inline bool operator> (const DbpCurrency& cur) const;
	inline bool operator<=(const DbpCurrency& cur) const;
	inline bool operator>=(const DbpCurrency& cur) const;

  // Currency math
	inline DbpCurrency operator+(const DbpCurrency& cur) const;
  inline DbpCurrency operator+(long  nOperand);
	inline DbpCurrency operator-(const DbpCurrency& cur) const;
  inline DbpCurrency operator-(long  nOperand);
	inline const DbpCurrency& operator+=(const DbpCurrency& cur);
	inline const DbpCurrency& operator-=(const DbpCurrency& cur);
	inline DbpCurrency operator-() const;
	inline DbpCurrency operator*(long nOperand) const;
	inline DbpCurrency operator/(long nOperand) const;
	inline const DbpCurrency& operator*=(long nOperand);
	inline const DbpCurrency& operator/=(long nOperand);
private :
  OmsTypeInt64 val;
#ifdef AIX
  inline DbpCurrency(OmsTypeInt64);
#else
  explicit inline DbpCurrency(OmsTypeInt64);
#endif
};

// Implementation

inline DbpCurrency::DbpCurrency(OmsTypeInt64 i)
{
  val = i;
}

inline OmsTypeInt64 DbpCurrency::dbpGetVal() const
{
  return val;
}

inline void DbpCurrency::dbpPutVal(OmsTypeInt64 v)
{
  val = v;
}

inline DbpCurrency::DbpCurrency(const OmsTypePacked_8_3& p)
{
  OmsPacked *pp = REINTERPRET_CAST(OmsPacked*,CONST_CAST(OmsTypePacked_8_3*,&p));
  val = pp->toInt64_16();
}

inline void DbpCurrency::dbpToPacked_8_3 (OmsTypePacked_8_3& p)
{
  OmsPacked *pp = REINTERPRET_CAST(OmsPacked*,&p);
  pp->toPacked(val, 8);
}

inline DbpCurrency::operator OmsTypePacked_8_3()
{
  OmsTypePacked_8_3 p;
  dbpToPacked_8_3(p);
  return p;
};

inline const DbpCurrency& DbpCurrency::operator =( const OmsTypePacked_8_3& cur )
{
  OmsPacked *pp = REINTERPRET_CAST(OmsPacked*,CONST_CAST(OmsTypePacked_8_3*,&cur));
  val      = pp->toInt64_16();
  return *this;
}


inline bool DbpCurrency::operator==(const DbpCurrency& cur) const
{
  return (val == cur.val);
}

inline bool DbpCurrency::operator!=(const DbpCurrency& cur) const
{
  return (val != cur.val);
}

inline bool DbpCurrency::operator< (const DbpCurrency& cur) const
{
  return (val < cur.val);
}

inline bool DbpCurrency::operator> (const DbpCurrency& cur) const
{
  return (val > cur.val);
}

inline bool DbpCurrency::operator<=(const DbpCurrency& cur) const
{
  return (val <= cur.val);
}

inline bool DbpCurrency::operator>=(const DbpCurrency& cur) const
{
  return (val >= cur.val);
}

inline DbpCurrency DbpCurrency::operator+(const DbpCurrency& s) const
{
  return DbpCurrency (val + s.val);
}

inline DbpCurrency DbpCurrency::operator+(long nOperand)
{
  OmsTypeInt64 op = nOperand * DBP_CURRENCY_1;
  return DbpCurrency (val + op);
}

inline DbpCurrency DbpCurrency::operator-(const DbpCurrency& s) const
{
  return DbpCurrency (val - s.val);
}

inline DbpCurrency DbpCurrency::operator-(long nOperand)
{
  DbpCurrency op(nOperand * DBP_CURRENCY_1);
  return (*this - op);
}

inline const DbpCurrency& DbpCurrency::operator+=(const DbpCurrency& cur)
{
  val += cur.val;
  return *this;
}

inline const DbpCurrency& DbpCurrency::operator-=(const DbpCurrency& cur)
{
  val -= cur.val;
  return *this;
}

inline DbpCurrency DbpCurrency::operator-() const
{
  return DbpCurrency(-val);
}

inline DbpCurrency DbpCurrency::operator*(long nOperand) const
{
  return DbpCurrency(val * nOperand);
}

inline DbpCurrency DbpCurrency::operator/(long nOperand) const
{
  return DbpCurrency(val / nOperand);
}

inline const DbpCurrency& DbpCurrency::operator*=(long nOperand)
{
  val *= nOperand;
  return *this;
}

inline const DbpCurrency& DbpCurrency::operator/=(long nOperand)
{
  val /= nOperand;
  return *this;
}

#endif

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/co/hco14.h <==
/* @lastChanged: "1998-06-22  16:21"

  * @filename:   hco00.h
  * @purpose:    "Currency Interface for C++ Persistent Objects"
  * @release:    7.1.0.0
  * @see:        "http://www.bea.sap-ag.de/doku/rel-7.1/hco00.html"
  *
  * @copyright:  "Copyright by   SAP AG, 1998"


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*/

#if !defined (__liveCacheCurrency_INCLUDED)
#define __liveCacheCurrency_INCLUDED

#include "livecache.h" // nocheck

#define MAX_CURRENCY_VAL 9223372036854775807I64
#define DBP_CURRENCY_1   1000

class DECLSPEC_IMPORT OmsPacked {
public :
  OmsTypeInt64 toInt64_16();
  void   toPacked(OmsTypeInt64,int);
private :
 unsigned char m_packed[16];      
};

class DbpCurrency {
public :
  DbpCurrency(){}
  
  inline DbpCurrency(const OmsTypePacked_8_3&);
  inline void dbpToPacked_8_3 (OmsTypePacked_8_3&);
  inline operator OmsTypePacked_8_3();
  inline OmsTypeInt64 dbpGetVal() const;
  inline void dbpPutVal(OmsTypeInt64);

  inline const DbpCurrency& operator =( const OmsTypePacked_8_3& cur );

  // Currency Comparison
  inline bool operator==(const DbpCurrency& cur) const;
	inline bool operator!=(const DbpCurrency& cur) const;
	inline bool operator< (const DbpCurrency& cur) const;
	inline bool operator> (const DbpCurrency& cur) const;
	inline bool operator<=(const DbpCurrency& cur) const;
	inline bool operator>=(const DbpCurrency& cur) const;

  // Currency math
	inline DbpCurrency operator+(const DbpCurrency& cur) const;
  inline DbpCurrency operator+(long  nOperand);
	inline DbpCurrency operator-(const DbpCurrency& cur) const;
  inline DbpCurrency operator-(long  nOperand);
	inline const DbpCurrency& operator+=(const DbpCurrency& cur);
	inline const DbpCurrency& operator-=(const DbpCurrency& cur);
	inline DbpCurrency operator-() const;
	inline DbpCurrency operator*(long nOperand) const;
	inline DbpCurrency operator/(long nOperand) const;
	inline const DbpCurrency& operator*=(long nOperand);
	inline const DbpCurrency& operator/=(long nOperand);
private :
  OmsTypeInt64 val;
#ifdef AIX
  inline DbpCurrency(OmsTypeInt64);
#else
  explicit inline DbpCurrency(OmsTypeInt64);
#endif
};

// Implementation

inline DbpCurrency::DbpCurrency(OmsTypeInt64 i)
{
  val = i;
}

inline OmsTypeInt64 DbpCurrency::dbpGetVal() const
{
  return val;
}

inline void DbpCurrency::dbpPutVal(OmsTypeInt64 v)
{
  val = v;
}

inline DbpCurrency::DbpCurrency(const OmsTypePacked_8_3& p)
{
  OmsPacked *pp = REINTERPRET_CAST(OmsPacked*,CONST_CAST(OmsTypePacked_8_3*,&p));
  val = pp->toInt64_16();
}

inline void DbpCurrency::dbpToPacked_8_3 (OmsTypePacked_8_3& p)
{
  OmsPacked *pp = REINTERPRET_CAST(OmsPacked*,&p);
  pp->toPacked(val, 8);
}

inline DbpCurrency::operator OmsTypePacked_8_3()
{
  OmsTypePacked_8_3 p;
  dbpToPacked_8_3(p);
  return p;
};

inline const DbpCurrency& DbpCurrency::operator =( const OmsTypePacked_8_3& cur )
{
  OmsPacked *pp = REINTERPRET_CAST(OmsPacked*,CONST_CAST(OmsTypePacked_8_3*,&cur));
  val      = pp->toInt64_16();
  return *this;
}


inline bool DbpCurrency::operator==(const DbpCurrency& cur) const
{
  return (val == cur.val);
}

inline bool DbpCurrency::operator!=(const DbpCurrency& cur) const
{
  return (val != cur.val);
}

inline bool DbpCurrency::operator< (const DbpCurrency& cur) const
{
  return (val < cur.val);
}

inline bool DbpCurrency::operator> (const DbpCurrency& cur) const
{
  return (val > cur.val);
}

inline bool DbpCurrency::operator<=(const DbpCurrency& cur) const
{
  return (val <= cur.val);
}

inline bool DbpCurrency::operator>=(const DbpCurrency& cur) const
{
  return (val >= cur.val);
}

inline DbpCurrency DbpCurrency::operator+(const DbpCurrency& s) const
{
  return DbpCurrency (val + s.val);
}

inline DbpCurrency DbpCurrency::operator+(long nOperand)
{
  OmsTypeInt64 op = nOperand * DBP_CURRENCY_1;
  return DbpCurrency (val + op);
}

inline DbpCurrency DbpCurrency::operator-(const DbpCurrency& s) const
{
  return DbpCurrency (val - s.val);
}

inline DbpCurrency DbpCurrency::operator-(long nOperand)
{
  DbpCurrency op(nOperand * DBP_CURRENCY_1);
  return (*this - op);
}

inline const DbpCurrency& DbpCurrency::operator+=(const DbpCurrency& cur)
{
  val += cur.val;
  return *this;
}

inline const DbpCurrency& DbpCurrency::operator-=(const DbpCurrency& cur)
{
  val -= cur.val;
  return *this;
}

inline DbpCurrency DbpCurrency::operator-() const
{
  return DbpCurrency(-val);
}

inline DbpCurrency DbpCurrency::operator*(long nOperand) const
{
  return DbpCurrency(val * nOperand);
}

inline DbpCurrency DbpCurrency::operator/(long nOperand) const
{
  return DbpCurrency(val / nOperand);
}

inline const DbpCurrency& DbpCurrency::operator*=(long nOperand)
{
  val *= nOperand;
  return *this;
}

inline const DbpCurrency& DbpCurrency::operator/=(long nOperand)
{
  val /= nOperand;
  return *this;
}

#endif
